import { EventType } from '@ucap-webmessenger/protocol-event';
import { FileType } from '@ucap-webmessenger/protocol-file';
import { JsonObject } from 'type-fest';
import { JsonAnalization } from '@ucap-webmessenger/api';

export class StringUtil {
  public static convertFinalEventMessage(
    eventType: EventType,
    finalEventMessage: string
  ): string | null {
    switch (eventType) {
      case EventType.Join:
      case EventType.Exit:
      case EventType.RenameRoom:
      case EventType.NotificationForTimerRoom:
      case EventType.GuideForRoomTimerChanged: {
        /**
         * 해당 타입은 메시지를 갱신하지 않는다.
         * @description Edit with ui-chat > messages.component.ts
         */
        return null;
      }
      case EventType.Sticker:
        finalEventMessage = '스티커';
        break;
      case EventType.File:
        {
          const contentJson = JSON.parse(finalEventMessage);
          if (contentJson.FileType === FileType.Image) {
            finalEventMessage = '이미지';
          } else {
            finalEventMessage = '첨부파일';
          }
        }
        break;
      case EventType.VideoConference:
        finalEventMessage = '화상회의';
        break;
      case EventType.MassText:
        {
          try {
            const json: JsonObject | Error = JsonAnalization.receiveAnalization(
              finalEventMessage
            );
            finalEventMessage = json.Content.toString();
          } catch (e) {
            finalEventMessage = '대용량 텍스트';
          }
        }
        break;

      default:
        return finalEventMessage;
    }
  }
}
